@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "gleam-ts-mode" "1.0.0"
+(define-package "gleam-ts-mode" "20251006.1500"
   "Major mode for Gleam."
   '((emacs "29.1"))
   :url "https://github.com/gleam-lang/gleam-mode"
-  :commit "91cf073c5fb889c091b1797f44cc52419b7c9ae2"
-  :revdesc "91cf073c5fb8"
+  :commit "bd4a0ea995cab2bd2676d04ff155eccd306f835d"
+  :revdesc "bd4a0ea995ca"
   :keywords '("languages" "gleam"))
