@@ -5,8 +5,8 @@
 ;;
 ;; URL: https://github.com/gleam-lang/gleam-mode
 ;; Keywords: languages gleam
-;; Package-Version: 1.0.0
-;; Package-Revision: 91cf073c5fb8
+;; Package-Version: 20251006.1500
+;; Package-Revision: bd4a0ea995ca
 ;; SPDX-License-Identifier: Apache-2.0 OR GPL-3.0-or-later
 ;; Package-Requires: ((emacs "29.1"))
 
@@ -178,7 +178,7 @@ A change to this setting only takes effect the next time the
             "use"
             ])
           (keywords (if (gleam-ts--grammar-supports-echo-keyword-p)
-                        (vconcat basic-keywords ["echo"])
+                        (append basic-keywords '("echo"))
                       basic-keywords)))
      (list keywords '@font-lock-keyword-face))
 
@@ -336,12 +336,11 @@ otherwise, it aligns with the initial expression."
 
 ;;; Public functions
 
-;;;###autoload
 (defun gleam-ts-install-grammar ()
   "Install the Gleam tree-sitter grammar."
   (interactive)
   (if (and (treesit-available-p) (boundp 'treesit-language-source-alist))
-      (let* ((language-source (list "https://github.com/gleam-lang/tree-sitter-gleam" gleam-ts--grammar-revision))
+      (let* ((language-source (list "https://github.com/gleam-lang/tree-sitter-gleam" :revision gleam-ts--grammar-revision))
              (treesit-language-source-alist
               (cons
                (cons 'gleam language-source)
@@ -349,7 +348,6 @@ otherwise, it aligns with the initial expression."
         (treesit-install-language-grammar 'gleam))
     (display-warning 'treesit "Emacs' treesit package does not appear to be available")))
 
-;;;###autoload
 (defun gleam-ts-format ()
   "Format the current buffer using the `gleam format' command."
   (interactive)
